from setuptools import setup

setup(name='distributions-violkim-04mar2023',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions-violkim-04mar2023'],
      author = 'Chester Kim',
      author_email = 'violkim@gmail.com',
      zip_safe=False)